pecos.misc.threshold\_curve
===========================

.. automodule:: pecos.misc.threshold_curve







   .. rubric:: Functions

   .. autosummary::

      func
      func2
      func3
      func4
      func5
      func6
      get_est
      get_i
      jackknife_d
      jackknife_p
      jackknife_pd
      threshold_fit
